"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DoorsDoorCloseEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player closes a specific door.
 */
class DoorsDoorCloseEvent extends events_1.RevertableEvent {
    constructor(room, doorsystem, message, 
    /**
     * The player that closed the door. Only available if the client is the
     * host.
     */
    player, 
    /**
     * The door that the player closed.
     */
    door) {
        super();
        this.room = room;
        this.doorsystem = doorsystem;
        this.message = message;
        this.player = player;
        this.door = door;
        this.eventName = "doors.close";
        this._alteredDoor = door;
    }
    /**
     * The alternate door that will be closed, if changed.
     */
    get alteredDoor() {
        return this._alteredDoor;
    }
    /**
     * Change the door that was closed.
     * @param door The door to close.
     */
    setDoor(door) {
        if (typeof door === "number") {
            return this.setDoor(this.doorsystem.doors[door]);
        }
        this._alteredDoor = door;
    }
}
exports.DoorsDoorCloseEvent = DoorsDoorCloseEvent;
DoorsDoorCloseEvent.eventName = "doors.close";
//# sourceMappingURL=Close.js.map