import { BasicEvent } from "@skeldjs/events";
import { StartMeetingMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a meeting is started, either by a player reporting a body or
 * calling an emergency meetting.
 *
 * This guarantees that the meeting has actually started, see
 * {@link PlayerReportDeadBodyEvent} for an event that can prevent a meeting from
 * being started if you are the host.
 */
export declare class PlayerStartMeetingEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: StartMeetingMessage | undefined;
    /**
     * The player who called the meeting, either by reporting a body or
     * calling an emergency meeting.
     */
    readonly caller: PlayerData<RoomType>;
    /**
     * The player of the body that was reported, or "emergency" if the
     * meeting is an emergency meeting.
     */
    readonly body: PlayerData<RoomType> | "emergency";
    static eventName: "player.startmeeting";
    eventName: "player.startmeeting";
    constructor(room: RoomType, player: PlayerData<RoomType>, message: StartMeetingMessage | undefined, 
    /**
     * The player who called the meeting, either by reporting a body or
     * calling an emergency meeting.
     */
    caller: PlayerData<RoomType>, 
    /**
     * The player of the body that was reported, or "emergency" if the
     * meeting is an emergency meeting.
     */
    body: PlayerData<RoomType> | "emergency");
}
//# sourceMappingURL=StartMeeting.d.ts.map