import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { ReactorSystem } from "../../systems";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { ReactorEvent } from "./ReactorEvent";
/**
 * Emitted when a player places their hand on a reactor console.
 */
export declare class ReactorConsoleAddEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, ReactorEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly reactor: ReactorSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that placed their hand on the console. Only available
     * if the client is the host.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The ID of the console that the player placed their hand on.
     */
    readonly consoleId: number;
    static eventName: "reactor.consoles.add";
    eventName: "reactor.consoles.add";
    private _alteredConsoleId;
    constructor(room: RoomType, reactor: ReactorSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that placed their hand on the console. Only available
     * if the client is the host.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The ID of the console that the player placed their hand on.
     */
    consoleId: number);
    /**
     * The ID of the altered console that will be added instead, if changed.
     */
    get alteredConsoleId(): number;
    /**
     * Change the console that the player placed their hand on.
     * @param consoleId The ID of the console to set.
     */
    setConsole(consoleId: number): void;
}
//# sourceMappingURL=ConsoleAdd.d.ts.map