"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SystemStatus = void 0;
const util_1 = require("@skeldjs/util");
const constant_1 = require("@skeldjs/constant");
const protocol_1 = require("@skeldjs/protocol");
const events_1 = require("@skeldjs/events");
class SystemStatus extends events_1.EventEmitter {
    constructor(ship, systemType, data) {
        super();
        this.ship = ship;
        if (data) {
            if (data instanceof util_1.HazelReader) {
                this.Deserialize(data, true);
            }
            else {
                this.patch(data);
            }
        }
        this.systemType = systemType;
        this._dirty = false;
    }
    get dirty() {
        return this._dirty;
    }
    set dirty(isDirty) {
        this._dirty = isDirty;
        this.ship.dirtyBit = 1;
    }
    patch(data) {
        Object.assign(this, data);
    }
    /**
     * Whether or not this system is sabotaged.
     */
    get sabotaged() {
        return false;
    }
    /**
     * Return the room that this system belongs to.
     */
    get room() {
        return this.ship.room;
    }
    async emit(event) {
        if (this.ship) {
            this.ship.emit(event);
        }
        return super.emit(event);
    }
    async emitSerial(event) {
        if (this.ship) {
            this.ship.emitSerial(event);
        }
        return super.emitSerial(event);
    }
    emitSync(event) {
        if (this.ship) {
            this.ship.emitSync(event);
        }
        return super.emitSync(event);
    }
    Deserialize(reader, spawn) {
        void reader, spawn;
    }
    Serialize(writer, spawn) {
        void writer, spawn;
    }
    async HandleRepair(player, amount, rpc) {
        void player, amount, rpc;
    }
    Detoriorate(delta) {
        void delta;
    }
    async HandleSabotage(player, rpc) {
        void player, rpc;
    }
    /**
     * Fully repair this system.
     */
    async repair() { }
    /**
     * Sabotage this system.
     */
    async sabotage() {
        var _a, _b;
        if (!((_a = this.room.myPlayer) === null || _a === void 0 ? void 0 : _a.control))
            return;
        if (this.room.hostIsMe) {
            await ((_b = this.ship.systems.get(constant_1.SystemType.Sabotage)) === null || _b === void 0 ? void 0 : _b.HandleRepair(this.room.myPlayer, this.systemType, undefined));
        }
        else {
            await this.room.broadcast([
                new protocol_1.RpcMessage(this.ship.netId, new protocol_1.RepairSystemMessage(constant_1.SystemType.Sabotage, this.room.myPlayer.control.netId, this.systemType))
            ], undefined, [this.room.hostId]);
        }
    }
    async _sendRepair(amount) {
        var _a;
        if (!((_a = this.room.myPlayer) === null || _a === void 0 ? void 0 : _a.control))
            return;
        await this.room.broadcast([
            new protocol_1.RpcMessage(this.ship.netId, new protocol_1.RepairSystemMessage(this.systemType, this.room.myPlayer.control.netId, amount))
        ], undefined, [this.room.hostId]);
    }
}
exports.SystemStatus = SystemStatus;
//# sourceMappingURL=SystemStatus.js.map